# Interpolate

ColorAide Extras provides a few experimental interpolation plugins

Methods                                | Description
-------------------------------------- | -----------
[`spectral`](./spectral.md)            | An interpolation plugin that allows for single constant Kubelka-Munk interpolation reflectance curves generated from the sRGB gamut.
[`spectral-continuous`](./spectral.md) | A continuous interpolation version of the `spectral` interpolator.
